@@ -10,7 +10,7 @@ use Data::Unixish::Util qw(%common_args);
 use Text::ANSI::Util qw(ta_wrap ta_mbwrap);
 use Text::WideChar::Util qw(mbwrap);
 
-our $VERSION = '1.33'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 our %SPEC;
 
@@ -19,7 +19,7 @@ $SPEC{wrap} = {
     summary => 'Wrap text',
     args => {
         %common_args,
-        columns => {
+        width => {
             summary => 'Target column width',
             schema =>[int => {default=>80, min=>1}],
             cmdline_aliases => { c=>{} },
@@ -38,7 +38,7 @@ $SPEC{wrap} = {
 sub wrap {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
-    my $cols = $args{columns} // 80;
+    my $w     = $args{width} // 80;
     my $ansi  = $args{ansi};
     my $mb    = $args{mb};
 
@@ -47,14 +47,14 @@ sub wrap {
             last if !defined($item) || ref($item);
             if ($ansi) {
                 if ($mb) {
-                    $item = ta_mbwrap($item, $cols);
+                    $item = ta_mbwrap($item, $w);
                 } else {
-                    $item = ta_wrap  ($item, $cols);
+                    $item = ta_wrap  ($item, $w);
                 }
             } elsif ($mb) {
-                $item = mbwrap($item, $cols);
+                $item = mbwrap($item, $w);
             } else {
-                $item = Text::WideChar::Util::wrap($item, $cols);
+                $item = Text::WideChar::Util::wrap($item, $w);
             }
         }
         push @$out, $item;
@@ -77,14 +77,14 @@ Data::Unixish::wrap - Wrap text
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =head1 SYNOPSIS
 
 In Perl:
 
  use Data::Unixish::List qw(dux);
- $wrapped = dux([wrap => {columns=>20}], "xxxx xxxx xxxx xxxx xxxx"); # "xxxx xxxx xxxx xxxx\nxxxx"
+ $wrapped = dux([wrap => {width=>20}], "xxxx xxxx xxxx xxxx xxxx"); # "xxxx xxxx xxxx xxxx\nxxxx"
 
 In command line:
 
